pub struct Pool<VS: VersionSet, N: PackageName = String> { /* private fields */ }Expand description
A pool stores and internalizes data related to the available packages.
A pool never releases its memory until it is dropped. References returned by
the pool will remain valid for the lifetime of the pool. This allows
inserting into the pool without requiring a mutable reference to the pool.
This is what we refer to as Frozen data can be added but old data can
never be removed or mutated.
Implementations
Sourceimpl<VS: VersionSet, N: PackageName> Pool<VS, N>
impl<VS: VersionSet, N: PackageName> Pool<VS, N>
Sourcepub fn intern_string(&self, name: impl Into<String> + AsRef<str>) -> StringId
pub fn intern_string(&self, name: impl Into<String> + AsRef<str>) -> StringId
Interns a generic string into the Pool and returns its StringId.
Strings are deduplicated.
Sourcepub fn resolve_string(&self, string_id: StringId) -> &str
pub fn resolve_string(&self, string_id: StringId) -> &str
Returns the string associated with the provided StringId.
Panics if the string is not found in the pool.
Sourcepub fn intern_package_name<NValue>(&self, name: NValue) -> NameId
pub fn intern_package_name<NValue>(&self, name: NValue) -> NameId
Interns a package name into the Pool, returning its NameId. Names
are deduplicated. If the same name is inserted twice the same
NameId will be returned.
The original name can be resolved using the
Self::resolve_package_name function.
Sourcepub fn resolve_package_name(&self, name_id: NameId) -> &N
pub fn resolve_package_name(&self, name_id: NameId) -> &N
Returns the package name associated with the provided NameId.
Panics if the package name is not found in the pool.
Sourcepub fn lookup_package_name(&self, name: &N) -> Option<NameId>
pub fn lookup_package_name(&self, name: &N) -> Option<NameId>
Returns the NameId associated with the specified name or None if
the name has not previously been interned using
Self::intern_package_name.
Sourcepub fn intern_solvable(&self, name_id: NameId, record: VS::V) -> SolvableId
pub fn intern_solvable(&self, name_id: NameId, record: VS::V) -> SolvableId
Adds a solvable to a repo and returns it’s SolvableId.
Unlike some of the other interning functions this function does not deduplicate any of the inserted elements. A unique Id will be returned everytime this function is called.
Sourcepub fn resolve_solvable(&self, id: SolvableId) -> &Solvable<VS::V>
pub fn resolve_solvable(&self, id: SolvableId) -> &Solvable<VS::V>
Returns the solvable associated to the provided id
Panics if the solvable is not found in the pool
Sourcepub fn intern_version_set(
&self,
package_name: NameId,
version_set: VS,
) -> VersionSetId
pub fn intern_version_set( &self, package_name: NameId, version_set: VS, ) -> VersionSetId
Interns a version set into the Pool, returning its VersionSetId.
The returned VersionSetId can be used to retrieve a reference to
the original version set using [Self::resolve_version-set].
A version set is always associated with a specific package name to which
it applies. The passed in package name can be retrieved using
Self::resolve_version_set_package_name.
Version sets are deduplicated. This means that if the same version set
is inserted twice they will share the same VersionSetId.
Sourcepub fn resolve_version_set(&self, id: VersionSetId) -> &VS
pub fn resolve_version_set(&self, id: VersionSetId) -> &VS
Returns the version set associated with the provided id
Panics if the version set is not found in the pool
Sourcepub fn resolve_version_set_package_name(&self, id: VersionSetId) -> NameId
pub fn resolve_version_set_package_name(&self, id: VersionSetId) -> NameId
Returns the package name associated with the provide id.
Panics if the version set is not found in the pool
Sourcepub fn intern_version_set_union(
&self,
first: VersionSetId,
others: impl Iterator<Item = VersionSetId>,
) -> VersionSetUnionId
pub fn intern_version_set_union( &self, first: VersionSetId, others: impl Iterator<Item = VersionSetId>, ) -> VersionSetUnionId
Interns a union of two or more version sets and returns its
VersionSetUnionId.
Version set unions are not deduplicated, and a unique id is returned on every invocation.
Sourcepub fn resolve_version_set_union(
&self,
id: VersionSetUnionId,
) -> impl Iterator<Item = VersionSetId> + '_
pub fn resolve_version_set_union( &self, id: VersionSetUnionId, ) -> impl Iterator<Item = VersionSetId> + '_
Returns the version sets in the version set union with the given id.
Panics if there is no union with the given id.
Sourcepub fn resolve_condition(&self, id: ConditionId) -> &Condition
pub fn resolve_condition(&self, id: ConditionId) -> &Condition
Resolve the condition associated with the provided id.
Sourcepub fn intern_condition(&self, condition: Condition) -> ConditionId
pub fn intern_condition(&self, condition: Condition) -> ConditionId
Interns a condition into the pool and returns its ConditionId.
Conditions are deduplicated, so if the same condition is inserted
twice the same ConditionId will be returned.